@@ -79,4 +79,32 @@ class Database():
         
         rows = cursor.fetchall()
         
-        return rows
\ No newline at end of file
+        return rows
+    
+    def insert_row(self, table, columns, values):
+        """ Inserts a row into a specified table in the active database """
+        
+        sql = "INSERT INTO {table} (".format(table=table)
+        
+        for column in columns:
+            sql += "{column}".format(column=column)
+            if columns.index(column) == len(columns) - 1:
+                sql += ") VALUES ("
+            else:
+                sql += ", "
+        
+        for value in values:
+            sql += "%s"
+            if values.index(value) == len(values) - 1:
+                sql += ");"
+            else:
+                sql += ", "
+        
+        print("Preparing insert statement: {sql} with values: ".format(sql=sql), values)
+        
+        cursor = self.get_cursor()
+        cursor.execute(sql, values)
+        
+        self.connection.commit()
+        
+        print("Successfully inserted a new record into the {table} table.".format(table=table))
\ No newline at end of file
