@@ -1,6 +1,6 @@
-from src.lib.tables import Table
-from src.lib.columns import IdColumn, VarcharColumn, TextColumn
-from src.lib.columns.commons import CreatedByIdColumn, CreatedAtColumn, UpdatedAtColumn
+from mypydb.tables import Table
+from mypydb.columns import IdColumn, VarcharColumn, TextColumn
+from mypydb.columns.commons import CreatedByIdColumn, CreatedAtColumn, UpdatedAtColumn
 
 
 class CategoriesTable(Table):
